/* categories */
#ccgallery.list .media{
	padding: 1em;
}
#ccgallery .gallery-item{
	position: relative;
	border: 1px solid #2e2e2e;
}
	#ccgallery .gallery-item p{
		text-align: center;
	}
/* item */
#ccgallery .media div{
	display: inline-block;
	vertical-align: top;
}
#ccgallery .media div a{
	text-decoration: none;
}
#ccgallery .media .large{
	width: 67%;
}
	#ccgallery .media .large img{
		width: 100%;
		max-width: 100%;
	}

#ccgallery .media .thumbs{
	width: 30%;
	text-align: right;
}
	#ccgallery .media .thumbs a{
		opacity: 0.6;
		-webkit-transition: all 0.2s ease-in-out;
		-moz-transition: all 0.2s ease-in-out;
		-o-transition: all 0.2s ease-in-out;
		-ms-transition: all 0.2s ease-in-out;
	}
		#ccgallery .media .thumbs a:hover{
			opacity: 1;
		}
	#ccgallery .media .thumbs img{
		width: 45%;
		padding: 0;
		margin: 1%;
		display: inline-block;
	}
