/*
 * START ITEM ADMIN
 */
fieldset.content div input,
fieldset.other div input,
fieldset.content div textarea#id_description{
	width: 97%;
	padding: 10px;
	font-size: 14px;
}
fieldset.content div textarea#id_description{
	height: 48px;
}
/* widths on the name and status */
div.form-row.field-name,
div.form-row.field-status{
	border-bottom: 0 none;
	width: 45%;
	margin: 0;
	padding: 10px 10px;
	display: inline-block;
	vertical-align: top;
}
div.form-row.field-name{
	width: 80%;
}

div.form-row.field-status{
	width: 15%;
}
div.form-row.field-status select#id_status{
	margin-top: 10px;
	width: 100%;
}
div.form-row.field-description{
	border-top: 1px solid #EEE;
}
/* slug and date */

div.form-row.field-slug,
div.form-row.field-created{
	display: inline-block;
	vertical-align: top;
}
div.form-row.field-slug,
div.form-row.field-created{
	width: 48%;
}

fieldset.other div.form-row.field-created input{
	width: 100px;
}
/* select boxes */
.selector{
	width: 100%;
}
#id_categories_filter{
	display: none;
}
.selector-available,
.selector-chosen{
	width: 48%;
}
.selector-available select{
	height: 300px;
}
.selector-available select,
.selector-chosen select{
	height: 100px !important;
	width: 100%;
}
.field-categories .selector ul.selector-chooser{

	margin-top: 3em;
}
.selector-chosen a,
.selector-available a,
.field-categories p.help{
	display: none;
}
/*
 * END ITEM ADMIN
 */
