{% extends 'ccgallery/base.html' %}

{% block title %} {{category.name}} &ndash; {% endblock %}

{% block body_class %}list{% endblock %}

{% block ccgallery_breadcrumbs %}
	<a href="{{category.get_absolute_url}}">{{category.name}}</a>
{% endblock %}

{% block body %}

	<div class="media">
		<h1> {{category.name}} </h1>
	{% for item in items %}
		<div class="gallery-item">
			{% with item.image as image %}
			<a
				href="{% url ccgallery:item category.slug item.slug %}">
				<img
					src="{{image.src.url_200x200}}"
					alt="{{image.caption}}">
			</a>
			<p>
				<a
					href="{% url ccgallery:item category.slug item.slug %}">
					{{item.name}}
				</a>
			<p>
			{% endwith %}
		</div>
	{% endfor %}
	</div>
{% endblock %}
