{% extends 'ccgallery/base.html' %}

{% block title %} Gallery &ndash; {% endblock %}

{% block body_class %}list{% endblock %}

{% block body %}
	<div class="media">
	{% for category in categories %}
		<div class="gallery-item">
			{% with category.image as image %}
			<a
				href="{{category.get_absolute_url}}">
				<img
					src="{{image.src.url_200x200}}"
					alt="{{image.caption}}">
			</a>
			<p>
				<a
					href="{{category.get_absolute_url}}">
					{{category.name}}
				</a>
			<p>
			{% endwith %}
		</div>
	{% endfor %}
	</div>
{% endblock %}
